@@ -3,7 +3,7 @@ URL="http://johnhommer.com/academic/code/aghermann/Experiment.tar.bz2"
 TARBALL=Experiment.tar.bz2
 echo "
 Now downloading sample data.
-Press Ctl-C to interrupt.
+Press Ctrl+C to interrupt.
 "
 function kill_wget
 {
