@@ -149,8 +149,10 @@ save()
 
 int
 CStorablePPack::
-delete_file() const
+delete_file()
 {
+        APPLOG_INFO ("deleting %s", path().c_str());
+        saved = true;
         return unlink( path().c_str());
 }
 
