@@ -120,9 +120,9 @@ CExpDesign (const string& session_dir_,
                 if ( stst == 0 ) {
                         const char *lock_mtime_s = ctime( &stat0.st_mtime);
                         throw invalid_argument
-                                (sasprintf("A lock file exists:\n<i>%s</i>,\ncreated %.*s).\n\n"
+                                (sasprintf("A lock file exists (created %.*s):\n\n<i>%s</i>\n\n"
                                            "If this lock is stale, delete it and try again.",
-                                           lock_fname.c_str(), (int)strlen(lock_mtime_s)-1, lock_mtime_s));
+                                           (int)strlen(lock_mtime_s)-1, lock_mtime_s, lock_fname.c_str()));
                 }
                 open( lock_fname.c_str(), O_WRONLY|O_CREAT|O_TRUNC, 0600);
                 stst = stat( lock_fname.c_str(), &stat0);
