@@ -43,8 +43,10 @@ CScoreAssistant (const string& name_,
         status (0),
         lua_state (nullptr)
 {
-        if ( load() )
+        if ( load() ) {
                 APPLOG_WARN ("no script loaded from \"%s\"", path().c_str());
+                throw invalid_argument ("no script loaded");
+        }
 }
 
 CScoreAssistant::
@@ -83,6 +85,9 @@ int
 CScoreAssistant::
 save() const
 {
+        if ( saved || level == TExpDirLevel::transient || level == TExpDirLevel::system )
+                return 0;
+
         string p = path();
         if ( fs::mkdir_with_parents( fs::dirname(p)) ) {
                 APPLOG_WARN ("mkdir(\"%s\") failed: %s", p.c_str(), strerror(errno));
@@ -111,12 +116,6 @@ int
 CScoreAssistant::
 compile()
 {
-        if ( script_contents.empty() ) {
-                APPLOG_WARN ("no script to compile");
-                status |= TFlags::ecompile;
-                return -1;
-        }
-
         lua_init();
         lua_settop( lua_state, 0);
         int ret1 = luaL_loadbuffer(
