@@ -40,8 +40,8 @@ prepare_for_expdesign()
 {
       // tell me what they are
         client_pointer =
-                gdk_device_manager_get_client_pointer(
-                        gdk_display_get_device_manager( gdk_display_get_default()));
+                gdk_seat_get_pointer(
+                        gdk_display_get_default_seat( gdk_display_get_default()));
 
         GResource
                 *gresource
