@@ -68,10 +68,7 @@ SModelrunFacility (agh::ach::CModelRun& csim, SExpDesignUI& parent)
                         "Simulation: %s (%s) in %s (%s)",
                         csim.subject(), csim.session(), csim.channel(),
                         csim.P().display_name().c_str()));
-        gtk_window_set_default_size(
-                wModelrunFacility,
-                gdk_screen_get_width( gdk_screen_get_default()) * .80,
-                gdk_screen_get_height( gdk_screen_get_default()) * .55);
+        set_window_size_as_screen_fraction( wModelrunFacility, .80, .55);
 
         gtk_toggle_button_set_active( (GtkToggleButton*)eMFDB1, csim.ctl_params.DBAmendment1);
         gtk_toggle_button_set_active( (GtkToggleButton*)eMFDB2, csim.ctl_params.DBAmendment2);
