@@ -334,7 +334,7 @@ iExpGloballyScore_activate_cb(
                 filter =
                 [&]( SEpisode& E)
                 {
-                        return true;  // R.signal_type() == sigfile::SChannel::TType::eeg;
+                        return true;  // R.signal_type() == sigfile::definitions::types::eeg;
                 };
             break;
 
@@ -364,7 +364,7 @@ iExpGloballyScore_activate_cb(
 
         for ( auto& SF : ED.open_scoring_facilities ) {
                 for ( auto& H : SF->channels )
-                        if ( H.type() == sigfile::SChannel::TType::eeg )
+                        if ( H.type() == sigfile::definitions::types::eeg )
                                 H.get_signal_filtered();
                 SF->queue_redraw_all();
         }
@@ -460,7 +460,7 @@ iExpGloballyDetectArtifacts_activate_cb(
                 };
                 filter = [&]( SEpisode& E)
                 {
-                        return true;  // R.signal_type() == sigfile::SChannel::TType::eeg;
+                        return true;  // R.signal_type() == sigfile::definitions::types::eeg;
                 };
             break;
 
@@ -490,7 +490,7 @@ iExpGloballyDetectArtifacts_activate_cb(
 
         for ( auto& SF : ED.open_scoring_facilities ) {
                 for ( auto& H : SF->channels )
-                        if ( H.type() == sigfile::SChannel::TType::eeg )
+                        if ( H.type() == sigfile::definitions::types::eeg )
                                 H.get_signal_filtered();
                 SF->queue_redraw_all();
         }
@@ -568,7 +568,7 @@ iExpGloballySetFilters_activate_cb(
 
                 for ( auto& SF : ED.open_scoring_facilities ) {
                         for ( auto& H : SF->channels )
-                                if ( H.type() == sigfile::SChannel::TType::eeg )
+                                if ( H.type() == sigfile::definitions::types::eeg )
                                         H.get_signal_filtered();
                         SF->queue_redraw_all();
                 }
@@ -649,10 +649,3 @@ iExpQuit_activate_cb(
 
 
 } // extern "C"
-
-// Local Variables:
-// Mode: c++
-// indent-tabs-mode: nil
-// tab-width: 8
-// c-basic-offset: 8
-// End:
