@@ -122,8 +122,7 @@ daSubjectTimeline_button_press_event_cb(
                 gtk_widget_set_visible( (GtkWidget*)ED.iSubjectTimelineScore, episode_ops);
                 gtk_widget_set_visible( (GtkWidget*)ED.iSubjectTimelineDetectUltradianCycle, episode_ops);
                 gtk_widget_set_visible( (GtkWidget*)ED.iSubjectTimelineEDFInfo, episode_ops);
-                gtk_menu_popup( ED.iiSubjectTimeline,
-                                NULL, NULL, NULL, NULL, 3, event->time);
+                gtk_menu_popup_at_pointer( ED.iiSubjectTimeline, (GdkEvent*)event);
             break;
         }
 
