@@ -305,6 +305,17 @@ annotation_type_s( const sigfile::SAnnotation::TType t)
         static const char* types[] = {"", "S", "K", "E"};
         return types[t];
 }
+
+cairo_t*
+gdk_cairo_create_wrapper(agh::ui::SExpDesignUI::SSubjectPresentation& J)
+{
+        return cairo_create(
+                gdk_window_create_similar_surface(
+                        gtk_widget_get_window( J.da),
+                        CAIRO_CONTENT_COLOR_ALPHA,
+                        J.tl_width(), J.tl_height()));
+
+}
 }
 
 void
@@ -449,10 +460,10 @@ populate_1()
                 timeline_end - timeline_start;
         if ( full_secs < 3600 )
                 full_secs = 3600;
-        tl_width = full_secs * tl_pph;
+        tl_width = full_secs * tl_pph / 3600;
         tl_pages = full_secs / ED->psd_params.pagesize;
 
-        APPLOG_INFO ("populate_1(): common timeline is %zu pages:", tl_pages);
+        APPLOG_INFO ("populate_1(): common timeline is %zu pages (%zu):", tl_pages, tl_pph);
         {
                 string t {asctime( localtime(&earliest_start))};
                 t += asctime( localtime(&latest_end));
@@ -524,7 +535,7 @@ populate_1()
 
                         // determine tl_left_margin
                         {
-                                cairo_t *cr = gdk_cairo_create( gtk_widget_get_window( J.da));
+                                cairo_t *cr = gdk_cairo_create_wrapper( J);
                                 cairo_text_extents_t extents;
                                 cairo_select_font_face( cr, "serif", CAIRO_FONT_SLANT_ITALIC, CAIRO_FONT_WEIGHT_BOLD);
                                 cairo_set_font_size( cr, 11);
