@@ -148,7 +148,7 @@ SChannel (agh::CRecording& r,
                 // don't: interchannel_gap is rubbish yet
                 psd.focused_band = metrics::TBand::delta;
 
-        } else if ( type() == sigfile::SChannel::TType::emg ) {
+        } else if ( type() == sigfile::definitions::types::emg ) {
                 get_raw_profile();
 
                 hist_range_min = 0.;
@@ -323,7 +323,7 @@ SScoringFacility::SChannel::
 which_profile( const metrics::TType metric)
 {
         switch ( type() ) {
-        case sigfile::SChannel::TType::eeg:
+        case sigfile::definitions::types::eeg:
                 switch ( metric ) {
                 case metrics::TType::mc:
                         return tuple<metrics::TType, valarray<TFloat>&>(metric, mc.course);
@@ -409,7 +409,7 @@ detect_artifacts( const agh::ad::SComprehensiveArtifactDetectionPPack& P)
 
         calculate_dirty_percent();
         get_signal_filtered();
-        if ( type() == sigfile::SChannel::TType::eeg ) {
+        if ( type() == sigfile::definitions::types::eeg ) {
                 get_psd_course();
                 get_psd_in_bands();
                 get_spectrum( _p.cur_page());
@@ -442,7 +442,7 @@ mark_region_as_artifact( const bool do_mark)
 
         get_signal_filtered();
 
-        if ( type() == sigfile::SChannel::TType::eeg ) {
+        if ( type() == sigfile::definitions::types::eeg ) {
                 get_psd_course();
                 get_psd_in_bands();
                 get_spectrum( _p.cur_page());
@@ -509,8 +509,8 @@ update_channel_menu_items( const double x)
         gtk_check_menu_item_set_active( _p.iSFPageSelectionDrawEnvelope, draw_selection_envelope);
         gtk_check_menu_item_set_active( _p.iSFPageSelectionDrawDzxdf,    draw_selection_dzcdf);
 
-        bool    is_eeg = (type() == sigfile::SChannel::TType::eeg),
-                is_emg = (type() == sigfile::SChannel::TType::emg),
+        bool    is_eeg = (type() == sigfile::definitions::types::eeg),
+                is_emg = (type() == sigfile::definitions::types::emg),
                 have_profile = is_eeg or is_emg;
         gtk_widget_set_visible( (GtkWidget*)_p.iSFPageProfilesSubmenuSeparator, have_profile);
         gtk_widget_set_visible( (GtkWidget*)_p.iiSFPageProfiles,                have_profile);
@@ -549,7 +549,7 @@ update_power_menu_items()
 
         gtk_widget_set_visible(
                 (GtkWidget*)_p.iSFPowerDrawBands,
-                (type() == sigfile::SChannel::TType::eeg &&
+                (type() == sigfile::definitions::types::eeg &&
                  draw_psd));
         _p.suppress_redraw = false;
 }
@@ -611,11 +611,3 @@ _put_selection()
                 selection_SU = sssu.second[0];
         }
 }
-
-
-// Local Variables:
-// Mode: c++
-// indent-tabs-mode: nil
-// tab-width: 8
-// c-basic-offset: 8
-// End:
