@@ -189,7 +189,7 @@ SPatternsDialog (SScoringFacility& p_)
 
         W_V.reg( eSFFDIncrement,     &increment);
 
-        atomic_up();
+        protected_up();
 }
 
 SScoringFacility::SPatternsDialog::
