@@ -9,6 +9,7 @@
  *         License:  GPL
  */
 
+#include <gtk/gtk.h>
 #include "rk1968.hh"
 
 using namespace std;
@@ -68,23 +69,24 @@ SRK1968Dialog (SScoringFacility& p_)
         gtk_combo_box_set_model_properly(
                 eSFRKProfileList, mSFRKProfiles);
 
-        agh::ui::global::set_mono_font(
-                (GtkWidget*)eSFRKScript, agh::ui::global::css_mono10);
+        // agh::ui::global::set_mono_font(
+        //         (GtkWidget*)eSFRKScript, agh::ui::global::css_mono10);
 
         G_CONNECT_1 (wSFRK, show);
         G_CONNECT_1 (wSFRK, hide);
 
+        set_window_size_as_screen_fraction( (GtkWindow*)wSFRK, .4, .7);
+
         eSFRKProfileList_changed_cb_handler_id =
                 G_CONNECT_1 (eSFRKProfileList, changed);
         G_CONNECT_1 (bSFRKProfileSave,    clicked);
         G_CONNECT_1 (bSFRKProfileRevert,  clicked);
         G_CONNECT_1 (bSFRKProfileDiscard, clicked);
 
-        for ( auto& W : {tSFRKScript} )
-                g_signal_connect(
-                        W, "changed",
-                        (GCallback)eSFRK_any_profile_value_changed_cb,
-                        this);
+        g_signal_connect(
+                tSFRKScript, "changed",
+                (GCallback)eSFRK_any_profile_value_changed_cb,
+                this);
 
         G_CONNECT_1 (bSFRKPreview, toggled);
         G_CONNECT_1 (bSFRKApply,   clicked);
@@ -100,6 +102,7 @@ SRK1968Dialog (SScoringFacility& p_)
 
       // 2. dialog
         W_V.reg( tSFRKScript, &Pp2.script_contents);
+        protected_up();
 }
 
 SScoringFacility::SRK1968Dialog::
