@@ -99,8 +99,7 @@ daSFMontage_button_press_event_cb(
                                 (GtkContainer*)SF.iiSFICAPage,
                                 radio_item_setter, (gpointer)mapped);
                         SF.suppress_redraw = false;
-                        gtk_menu_popup( SF.iiSFICAPage,
-                                        NULL, NULL, NULL, NULL, 3, event->time);
+                        gtk_menu_popup_at_pointer( SF.iiSFICAPage, (GdkEvent*)event);
                 }
                 return TRUE;
         }
@@ -141,9 +140,7 @@ daSFMontage_button_press_event_cb(
                     break;
                 case 3:
                         Ch->update_power_menu_items();
-                        gtk_menu_popup(
-                                SF.iiSFPower,
-                                NULL, NULL, NULL, NULL, 3, event->time);
+                        gtk_menu_popup_at_pointer( SF.iiSFPower, (GdkEvent*)event);
                     break;
                 }
 
@@ -181,14 +178,11 @@ daSFMontage_button_press_event_cb(
                 case 3:
                         if ( (event->state & GDK_MOD1_MASK && SF.n_hidden > 0) ||
                              !(SF.n_hidden < (int)SF.channels.size()) )
-                                gtk_menu_popup( SF.iiSFPageHidden,
-                                                NULL, NULL, NULL, NULL, 3, event->time);
+                                gtk_menu_popup_at_pointer( SF.iiSFPageHidden, (GdkEvent*)event);
                         else {
                                 Ch->update_channel_menu_items( event->x);
                                 Ch->update_power_menu_items();
-                                gtk_menu_popup(
-                                        in_selection ? SF.iiSFPageSelection : SF.iiSFPage,
-                                        NULL, NULL, NULL, NULL, 3, event->time);
+                                gtk_menu_popup_at_pointer( in_selection ? SF.iiSFPageSelection : SF.iiSFPage, (GdkEvent*)event);
                         }
                     break;
 
@@ -362,8 +356,7 @@ daSFMontage_button_release_event_cb(
                         Ch->selectively_enable_selection_menu_items();
                         Ch->update_channel_menu_items( event->x);
                         if ( fabs(SF.using_channel->marquee_mstart - SF.using_channel->marquee_mend) > 5 ) {
-                                gtk_menu_popup( SF.iiSFPageSelection,
-                                                NULL, NULL, NULL, NULL, 3, event->time);
+                                gtk_menu_popup_at_pointer( SF.iiSFPageSelection, (GdkEvent*)event);
                         }
                         gtk_widget_queue_draw( wid);
 
