@@ -279,14 +279,16 @@ SScoringFacility (agh::CSubject& J,
                         "You can hide some using appropriate channel context menus.", channels.size() - n_hidden);
 
         {
+                GdkRectangle rect;
+                get_monitor_geometry( gtk_widget_get_window((GtkWidget*)wSF), &rect);
                 int bar_height;
                 gtk_widget_get_size_request( (GtkWidget*)cSFControlBar, NULL, &bar_height);
                 int optimal_win_height = min(
                         (int)(HypnogramHeight + bar_height + da_ht + 100),
-                        (int)(gdk_screen_get_height( gdk_screen_get_default()) * .95));
+                        (int)(rect.height * .95));
                 gtk_window_set_default_size(
                         wSF,
-                        gdk_screen_get_width( gdk_screen_get_default()) * .90,
+                        rect.width * .90,
                         optimal_win_height);
         }
 
