@@ -19,6 +19,27 @@ using namespace std;
 using namespace agh::ui;
 
 
+void
+agh::ui::
+get_monitor_geometry( GdkWindow    *window,
+                      GdkRectangle *geometry)
+{
+        GdkDisplay *display = gdk_display_get_default();
+        GdkMonitor *monitor = gdk_display_get_monitor_at_window( display, window);
+
+        gdk_monitor_get_geometry( monitor, geometry);
+}
+
+
+void
+agh::ui::
+set_window_size_as_screen_fraction( GtkWindow* window, double fx, double fy)
+{
+        GdkRectangle rect;
+        get_monitor_geometry( gtk_widget_get_window((GtkWidget*)window), &rect);
+        gtk_window_set_default_size( window, rect.width * fx, rect.height * fy);
+}
+
 
 // cairo
 
