@@ -10,10 +10,11 @@
  */
 
 
-#include <sys/stat.h>
-#include <sys/mman.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <signal.h>
+#include <sys/stat.h>
+#include <sys/mman.h>
 #include <cinttypes>
 #include <fstream>
 #include <sstream>
@@ -103,11 +104,6 @@ set_recording_time( const string& s)
 
 
 
-
-
-
-
-
 #define EOA '$'
 
 namespace {
@@ -136,11 +132,16 @@ CEDFFile (const string& fname_, const int flags_, agh::log::CLogFacility* log_fa
         _mmapping =
                 mmap( NULL,
                       _fsize,
-                      PROT_READ | PROT_WRITE, MAP_SHARED,
+                      PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_POPULATE,
                       _fd, 0);
         if ( _mmapping == (void*)-1 ) {
                 close( _fd);
-                throw length_error ("CEDFFile::CEDFFile(): mmap error");
+                throw invalid_argument (explain_status(_status |= TStatus::mmap_error));
+        }
+        if ( sigsetjmp(sj_env, 1) ) {
+                munmap( _mmapping, _fsize);
+                close( _fd);
+                throw invalid_argument (explain_status(_status |= TStatus::mmap_error));
         }
 
       // parse header
@@ -213,13 +214,18 @@ CEDFFile (const string& fname_, const TSubtype subtype_, const int flags_,
         _mmapping =
                 mmap( NULL,
                       _fsize,
-                      PROT_READ | PROT_WRITE, MAP_SHARED,
+                      PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_POPULATE,
                       _fd,
                       0);
         if ( _mmapping == (void*)-1 ) {
                 close( _fd);
                 throw invalid_argument (explain_status(_status |= TStatus::mmap_error));
         }
+        if ( sigsetjmp(sj_env, 1) ) {
+                munmap( _mmapping, _fsize);
+                close( _fd);
+                throw invalid_argument (explain_status(_status |= TStatus::mmap_error));
+        }
 
       // fill out some essential header fields
         channels.resize( channels_.size());
@@ -384,12 +390,6 @@ CEDFFile::
 
 
 
-
-
-
-
-
-
 void
 CEDFFile::
 _lay_out_header()
@@ -426,39 +426,50 @@ _lay_out_header()
 
 
 
-
 char*
 CEDFFile::
-_get_next_field( char *&field, const size_t fld_size) throw (TStatus)
+_get_next_field( char **field, const size_t fld_size) throw (TStatus)
 {
         if ( _fld_pos + fld_size > _fsize ) {
                 _status |= bad_header;
                 throw bad_header;
         }
 
-        field = (char*)_mmapping + _fld_pos;
+        *field = (char*)_mmapping + _fld_pos;
         _fld_pos += fld_size;
 
-        return field;
+        return *field;
 }
 
+
+
+
 int
 CEDFFile::
 _parse_header()
 {
+        {
+                struct sigaction lsa;
+                memset( (void*)&lsa, 0, sizeof(lsa));
+                lsa.sa_sigaction = trip_SIGBUS;
+                sigemptyset( &lsa.sa_mask);
+                sigaddset( &lsa.sa_mask, SIGBUS);
+                lsa.sa_flags = SA_SIGINFO;
+                sigaction(SIGBUS, &lsa, NULL);
+        }
         size_t  n_channels;
         try {
                 _fld_pos = 0;
-                _get_next_field( header.version_number,   8);
-                _get_next_field( header.patient_id,      80);
-                _get_next_field( header.recording_id,    80);
-                _get_next_field( header.recording_date,   8);
-                _get_next_field( header.recording_time,   8);
-                _get_next_field( header.header_length,    8);
-                _get_next_field( header.reserved,        44);
-                _get_next_field( header.n_data_records,   8);
-                _get_next_field( header.data_record_size, 8);
-                _get_next_field( header.n_channels,       4);
+                _get_next_field( &header.version_number,   8);
+                _get_next_field( &header.patient_id,      80);
+                _get_next_field( &header.recording_id,    80);
+                _get_next_field( &header.recording_date,   8);
+                _get_next_field( &header.recording_time,   8);
+                _get_next_field( &header.header_length,    8);
+                _get_next_field( &header.reserved,        44);
+                _get_next_field( &header.n_data_records,   8);
+                _get_next_field( &header.data_record_size, 8);
+                _get_next_field( &header.n_channels,       4);
 
                 if ( strncmp( header.version_number, version_string, 8) ) {
                         _status |= (bad_version | inoperable);
@@ -472,7 +483,7 @@ _parse_header()
                         ? TSubtype::edfplus_d
                         : TSubtype::edf;
 
-                size_t        header_length;
+                size_t  header_length;
 
                 header_length = n_data_records = data_record_size = n_channels = 0;
                 sscanf( header.header_length,    "%8zu", &header_length);
@@ -524,20 +535,20 @@ _parse_header()
 
                       // determine & validate signal types
                         for ( auto &H : channels ) {
-                                _get_next_field( H.header.label, 16);
+                                _get_next_field( &H.header.label, 16);
                                 // let libsigfile::SChannel ctor figure
                                 H.ucd = {trim( string (H.header.label, 16))};
                         }
                         for ( auto &H : channels )
                                 H.transducer_type =
-                                        trim( string (_get_next_field( H.header.transducer_type, 80), 80));
+                                        trim( string (_get_next_field( &H.header.transducer_type, 80), 80));
 
                         for ( auto &H : channels )
                                 H.physical_dim =
-                                        trim( string (_get_next_field( H.header.physical_dim, 8), 8));
+                                        trim( string (_get_next_field( &H.header.physical_dim, 8), 8));
 
                         for ( auto &H : channels ) {
-                                _get_next_field( H.header.physical_min, 8);
+                                _get_next_field( &H.header.physical_min, 8);
                                 if ( H.ucd.type() == sigfile::definitions::types::edf_annotation )
                                         continue;
                                 if ( sscanf( H.header.physical_min, "%8lg",
@@ -548,7 +559,7 @@ _parse_header()
                                 }
                         }
                         for ( auto &H : channels ) {
-                                _get_next_field( H.header.physical_max, 8);
+                                _get_next_field( &H.header.physical_max, 8);
                                 if ( H.ucd.type() == sigfile::definitions::types::edf_annotation )
                                         continue;
                                 if ( sscanf( H.header.physical_max, "%8lg",
@@ -560,7 +571,7 @@ _parse_header()
                         }
 
                         for ( auto &H : channels ) {
-                                _get_next_field( H.header.digital_min, 8);
+                                _get_next_field( &H.header.digital_min, 8);
                                 if ( H.ucd.type() == sigfile::definitions::types::edf_annotation )
                                         continue;
                                 if ( sscanf( H.header.digital_min, "%8d",
@@ -571,7 +582,7 @@ _parse_header()
                                 }
                         }
                         for ( auto &H : channels ) {
-                                _get_next_field( H.header.digital_max, 8);
+                                _get_next_field( &H.header.digital_max, 8);
                                 if ( H.ucd.type() == sigfile::definitions::types::edf_annotation )
                                         continue;
                                 if ( sscanf( H.header.digital_max, "%8d",
@@ -584,11 +595,11 @@ _parse_header()
 
                         for ( auto &H : channels )
                                 H.filtering_info.assign(
-                                        trim( string (_get_next_field( H.header.filtering_info, 80), 80)));
+                                        trim( string (_get_next_field( &H.header.filtering_info, 80), 80)));
 
                         for ( auto &H : channels ) {
                                 char *tail;
-                                string t {trim( string (_get_next_field( H.header.samples_per_record, 8), 8))};
+                                string t {trim( string (_get_next_field( &H.header.samples_per_record, 8), 8))};
                                 H.samples_per_record =
                                         strtoul( t.c_str(), &tail, 10);
                                 if ( tail == NULL || *tail != '\0' ) {
@@ -600,7 +611,7 @@ _parse_header()
 
                         for ( auto &H : channels )
                                 H.reserved.assign(
-                                        trim( string (_get_next_field( H.header.reserved, 32), 32)));
+                                        trim( string (_get_next_field( &H.header.reserved, 32), 32)));
                 }
         } catch (TStatus ex) {
                 return -1;
